// $Id: nrembrowser.widget.js,v 1.11.2.18 2010/08/11 20:34:01 aaron Exp $

/**
 * @file
 * JavaScript for the Node Reference/Embed Media Browser (nrembrowser) widget.
 */

// Add this to the jQuery namespace.
(function ($) {

  // Define the nrembrowser object.
  Drupal.nrembrowser = Drupal.nrembrowser || {};

  // Our 'global' variable for the dialog jQuery object.
  Drupal.nrembrowser.$dialog = null;

  /**
   * Helper function to build the browser.
   *
   * @param $link
   *  The jQuery object for the field link we're launching from.
   * @param _current
   *  The currently selected media node. In a form that may be parsed by
   *  nodereference autocomplete, such as 'Title [nid:XY]' or '[nid:NN]'.
   */
  Drupal.nrembrowser.dialog = function($link, _current) {
    var element =  $link.data('element');
    var fieldName = $link.data('fieldName');
    // Create our media browser dialog.
    Drupal.nrembrowser.$dialog = $('<div id="nrembrowser-dialog"></div>')
      .dialog({
        autoopen: false,
        modal: true,
        width: 642,
        title: 'Add media'
      })
      // Remove the dialog entirely from the DOM after closing.
      .bind( "dialogclose", function(event, ui) {
        $(this).remove();
      })
      // Store the passed parameters.
      .data('link', $link)
      .data('current', _current)
      // Store the referenced element to the dialog jquery data.
      .data('element', element)
      .data('fieldName', fieldName)
      .data('insertElement', $link.data('insertElement'))
      // Store the HTML of the original thumbnail.
      .data('currentThumbnail', $link.parent().siblings('.nrembrowser-thumbnail').html());
    // Grab the remote output for the browser.
    $.ajax({
      type: 'POST',
      dataType: 'json',
      url: Drupal.settings.nrembrowser.mediaBrowserUrl,
      data: { js: true, current: _current, field_name: fieldName },
      success: function(data, textStatus, XMLHttpRequest) {
        if (data.status) {
          // Open the browser.
          Drupal.nrembrowser.$dialog.html(data.data).dialog('open');
          // Attach any required behaviors to the browser.
          Drupal.attachBehaviors(Drupal.nrembrowser.$dialog);
        }
        else {
          // Failure...
        }
      },
      error: function(XMLHttpRequest, textStatus, errorThrown) {
        // Failure...
      }
    });
  }

  Drupal.nrembrowser.insert = function(nidWrapper) {
    // Also the newly selected thumbnail, if it was changed.
    var _thumbnail = Drupal.nrembrowser.$dialog.data('currentThumbnail');

    // We need the field element to change. The 'title' has [nid:123].
    var _value = $(_thumbnail).attr('title');

    // Change the value and thumbnail of the associated field, and ensure we
    // run the correct behaviors again.
    var $field = $(Drupal.nrembrowser.$dialog.data('element'));
    $field.val(_value).removeClass('nrembrowserReplaceTextfields-processed');
    $('#' + $field.attr('id') + '-wrapper-nrembrowser-thumbnail').html(_thumbnail).show()
    .children('a').removeClass('nrembrowserReplaceTextfields-processed');

    // Run the behaviors on the new thumbnail.
    Drupal.attachBehaviors($field.parent().parent());
  }

  /**
   * Replace the textfields with links to the browser.
   */
  Drupal.behaviors.nrembrowserReplaceTextfields = function(context) {
    for (var id in Drupal.settings.nrembrowser) {
      var textfield = '#' + id + '-nid-nid';
      var wrapper = textfield + '-wrapper';

      // Hide the autocomplete textfield.
      $(textfield, context).not('.nrembrowserReplaceTextfields-processed').addClass('nrembrowserReplaceTextfields-processed').hide();

      // Add a link to launch the browser.
      $(wrapper, context).not('.nrembrowserReplaceTextfields-processed').addClass('nrembrowserReplaceTextfields-processed').append(Drupal.settings.nrembrowser[id].launchLink);

      // Launch the browser when clicking the new link.
      $(wrapper + ' .nrembrowser-launch-link', context).not('.nrembrowserReplaceTextfields-processed').addClass('nrembrowserReplaceTextfields-processed').each(function() {
        $(this).attr('id', id + '-nid-nid-nrembrowser-link').bind('click', function() {
          // Launch the browser: @params $link, _current ('title [nid:NID]').
          Drupal.nrembrowser.dialog($(this), $(this).siblings('input').val());
          // Halt further processing.
          return false;
        })
        // Add the field we're adding media to.
        .data('element', textfield)
        .data('insertElement', Drupal.nrembrowser)
        .data('fieldName', Drupal.settings.nrembrowser[id].fieldName);
      });

      if (!$(wrapper + '-nrembrowser-thumbnail').html()) {
        $(wrapper + '-nrembrowser-thumbnail').hide();
      }

      // Link the thumbnail to that same link.
      $(wrapper + '-nrembrowser-thumbnail img:not(.nrembrowserReplaceTextfields-processed)').addClass('nrembrowserReplaceTextfields-processed').each(function() {
        // We have a thumbnail, so hide the launch link.
        $launchLink = $(wrapper + ' .nrembrowser-launch-link').hide();

        // Store the launch link to data for later reference.
        $(this).data('launchLink', $launchLink);

        // When we click the thumbnail, launch the browser.
        $(this).bind('click', function() {
          // Trigger the browser link.
          $(this).data('launchLink').click();
          // Halt further processing.
          return false;
        });
      });
    }
  }

  /**
   * Replace images with [[nid:123]] tags in content upon detaching editor.
   */
  Drupal.nrembrowser.markup = function(image) {
    var $content = $('<div>' + image + '</div>');
    $.each($('img.nrembrowser-thumbnail-image', $content), function (i, elem) {
      $(elem).replaceWith($(elem).attr('alt'));
    });
    return $content.html();
  }

  // Behaviors added to the basic media browser dialog form elements.
  Drupal.behaviors.nrembrowserPassSelection = function(context) {
      $('#nrembrowser-tabs ul#nrembrowser-tabs-list', context).parent().not('.nrembrowserPassSelection-processed')
        .addClass('nrembrowserPassSelection-processed')
        .tabs({
          load: function(event, ui) {
            // Attach any required behaviors to the browser.
            Drupal.attachBehaviors(ui.panel);
          },
          ajaxOptions: { beforeSend: function (XMLHttpRequest) {
          },
          success: function(data) {
          }}
        });

    // Bind AJAX to pager links.
    $('#nrembrowser-add .pager a:not(.nrembrowserPassSelection-processed)', context)
      .addClass('nrembrowserPassSelection-processed')
      .bind('click', function(e) {
          var serialized = $(this).serialize();
          serialized += '&js=1';
          var $this = $(this);
          $.ajax({
            url: $(this).attr('href'),
            cache: false,
            data: serialized,
            dataType: 'json',
            error: function(XMLHttpRequest, textStatus, errorThrown) {
            },
            success: function(data, textStatus, XMLHttpRequest) {
              if (data.status) {
                $this.parents('#nrembrowser-tab-wrapper').parent().html(data.data);
                // Attach any required behaviors to the browser.
                Drupal.attachBehaviors(Drupal.nrembrowser.$dialog);
              }
            },
            type: 'GET'
          });
          return false;
      });

    $('#nrembrowser-exposed-widgets form:not(.nrembrowserPassSelection-processed)', context)
      .addClass('nrembrowserPassSelection-processed')
      .bind('submit', function(e) {
        var serialized = $(this).serialize();
        serialized += '&js=1';
        var $this = $(this);
        $.ajax({
          url: $(this).attr('action'),
          cache: false,
          data: serialized,
          dataType: 'json',
          error: function(XMLHttpRequest, textStatus, errorThrown) {
          },
          success: function(data, textStatus, XMLHttpRequest) {
            if (data.status) {
              $this.parents('#nrembrowser-tab-wrapper').parent().html(data.data);
              // Attach any required behaviors to the browser.
              Drupal.attachBehaviors(Drupal.nrembrowser.$dialog);
            }
          },
          type: 'GET'
        });
        return false;
      });

    // After hitting OK, we need to change the value of the field.
    $('#nrembrowser-add-media-page-form:not(.nrembrowserPassSelection-processed)', context)
      .addClass('nrembrowserPassSelection-processed')
      .bind('submit', function() {
        nidWrapper = Drupal.nrembrowser.markup(Drupal.nrembrowser.$dialog.data('currentThumbnail'));

        // If this is for WYISYWG, then we need to grab the Style.
        if (nidWrapper && Drupal.nrembrowser.$dialog.data('fieldName') == 'wysiwyg' && Drupal.settings.nrembrowser.getStyleURL) {
          $.ajax({
            url: Drupal.settings.nrembrowser.getStyleURL,
            cache: false,
            data: 'nid=' + nidWrapper,
            dataType: 'json',
            error: function(XMLHttpRequest, textStatus, errorThrown) {
            },
            success: function(data, textStatus, XMLHttpRequest) {
              if (data.status) {
                Drupal.nrembrowser.$dialog.html(data.data);
                // Attach any required behaviors to the browser.
                Drupal.attachBehaviors(Drupal.nrembrowser.$dialog);
              }
            },
            type: 'GET'
          });
          return false;
        }
        else if (nidWrapper) {

          Drupal.nrembrowser.$dialog.data('insertElement').insert(nidWrapper);

          // Close the dialog.
          Drupal.nrembrowser.$dialog.dialog('close');
          Drupal.nrembrowser.$dialog.remove();
        }

        // Halt further processing.
        return false;
      });

    // Pass the selected node thumbnail data into the field or WYSIWYG.
    $('#nrembrowser-style-formatter-selector-form:not(.nrembrowserPassSelection-processed)', context)
      .addClass('nrembrowserPassSelection-processed')
      .bind('submit', function() {
        nidWrapper = Drupal.nrembrowser.markup(Drupal.nrembrowser.$dialog.data('currentThumbnail'));
        nidWrapper = nidWrapper.replace(']]', ';styleName:' + Drupal.nrembrowser.$dialog.data('styleName') + ']]');

        Drupal.nrembrowser.$dialog.data('insertElement').insert(nidWrapper);

        // Close the dialog.
        Drupal.nrembrowser.$dialog.dialog('close');
        Drupal.nrembrowser.$dialog.remove();

        // Halt further processing.
        return false;
      });

    // Bind clicking the thumbnail to selecting the corresponding radio.
    $('#nrembrowser-add .nrembrowser-thumbnail:not(.nrembrowserPassSelection-processed)', context).addClass('nrembrowserPassSelection-processed').each(function() {
      $(this).bind('click', function() {
        // Select the associated radio when clicking the thumbnail.
        $(this).closest('div.form-item').find('input').attr('checked', 1).trigger('change').focus();

        // Draw a rectangle around the selected thumbnail.
        $('#nrembrowser-add .nrembrowser-thumbnail').removeClass('selected');
        $(this).addClass('selected');

        // Halt further processing.
        return false;
      }).bind('dblclick', function() {
        // Double-clicking a thumbnail submits the form.
        $('#nrembrowser-add-media-page-form').submit();
      }).bind('keypress', function(event) {
        // Pressing enter after selecting a thumbnail submits the form.
        if (event.which == 13) {
          $('#nrembrowser-add-media-page-form').submit();
          // Halt further processing.
          return false;
        }
      });
    });

    // Change the selected thumbnail after making a new radio selection.
    $('#nrembrowser-add-media-page-form input[name=media]', context).not('.nrembrowserPassSelection-processed').addClass('nrembrowserPassSelection-processed').each(function() {
      $(this).bind('change', function() {
        // Store the associated thumbnail to the dialog's data.
        Drupal.nrembrowser.$dialog.data('currentThumbnail', $(this).closest('div.form-item').find('.nrembrowser-thumbnail').html());
      })
        // Hide the radio after binding the change function.
        .hide();
    });
  }

  // Load the style formatter selector into the frame for WYSIWYG.
  Drupal.nrembrowser.changeStyleFormatterSelector = function() {
    Drupal.nrembrowser.$dialog.data('styleName', $('#nrembrowser-style-formatter-selector-form select').val());
    $.ajax({
      url: Drupal.settings.nrembrowser.getStylePreviewURL,
      cache: false,
      data: 'nid=' + $('#nrembrowser-style-formatter-selector-form #edit-nid').val() + '&styleName=' + $('#nrembrowser-style-formatter-selector-form select').val(),
      dataType: 'json',
      error: function(XMLHttpRequest, textStatus, errorThrown) {
      },
      success: function(data, textStatus, XMLHttpRequest) {
        if (data.status) {
          $('#nrembrowser-style-formatter-selector-preview-wrapper').html(data.data);
          // Attach any required behaviors.
          Drupal.attachBehaviors($('#nrembrowser-style-formatter-selector-preview-wrapper'));
        }
      },
      type: 'GET'
    });
  }

  Drupal.behaviors.nrembrowserStyleFormatterSelector = function(context) {
    $('#nrembrowser-style-formatter-selector-form select:not(.nrembrowserStyleFormatterSelector-processed)')
      .addClass('nrembrowserStyleFormatterSelector-processed')
      .each(function() {
        $(this).bind('change', function(e) {
          Drupal.nrembrowser.changeStyleFormatterSelector();
        });
      });
    $('##nrembrowser-style-formatter-selector-form a:not(.nrembrowserStyleFormatterSelector-processed)')
      .addClass('nrembrowserStyleFormatterSelector-processed')
      .each(function() {
        $(this).bind('click', function(e) {
          // Ensure that clicking a link in a preview teaser doesn't send us away.
          return false;
        });
      })
  }

})(jQuery);
